@@ -1,7 +1,8 @@
 """
 Simple example that counts the number of changes in an osm diff file.
 
-Shows how to detect the different kind of modifications.
+Shows how to detect the different kind of modifications and how to
+use the handler generator function instead of a handler class.
 """
 import osmium as o
 import sys
@@ -13,7 +14,7 @@ class Stats(object):
         self.modified = 0
         self.deleted = 0
 
-    def add(self, o):
+    def __call__(self, o):
         if o.deleted:
             self.deleted += 1
         elif o.version == 1:
@@ -27,32 +28,24 @@ class Stats(object):
         print("%s deleted: %d" % (prefix, self.deleted))
 
 
-class FileStatsHandler(o.SimpleHandler):
-    def __init__(self):
-        super(FileStatsHandler, self).__init__()
-        self.nodes = Stats()
-        self.ways = Stats()
-        self.rels = Stats()
+def main(osmfile):
+    nodes = Stats()
+    ways = Stats()
+    rels = Stats()
 
-    def node(self, n):
-        self.nodes.add(n)
+    h = o.make_simple_handler(node=nodes, way=ways, relation=rels)
 
-    def way(self, w):
-        self.ways.add(w)
+    h.apply_file(osmfile)
 
-    def relation(self, r):
-        self.rels.add(r)
+    nodes.outstats("Nodes")
+    ways.outstats("Ways")
+    rels.outstats("Relations")
 
+    return 0
 
 if __name__ == '__main__':
     if len(sys.argv) != 2:
-        print("Usage: python osm_file_stats.py <osmfile>")
+        print("Usage: python %s <osmfile>" % sys.argv[0])
         sys.exit(-1)
 
-    h = FileStatsHandler()
-
-    h.apply_file(sys.argv[1])
-
-    h.nodes.outstats("Nodes")
-    h.ways.outstats("Ways")
-    h.rels.outstats("Relations")
+    exit(main(sys.argv[1]))
