@@ -7,6 +7,7 @@ import sys
 from textwrap import dedent
 import osmium
 from datetime import datetime
+from nose.tools import *
 
 if sys.version_info[0] == 3:
     from datetime import timezone
@@ -135,7 +136,7 @@ class HandlerTestBase:
     apply_locations = False
     apply_idx = 'flex_mem'
 
-    def test_func(self):
+    def test_apply_file(self):
         if isinstance(self.data, (list, tuple)):
             fn = create_osm_file(self.data)
         else:
@@ -150,6 +151,34 @@ class HandlerTestBase:
         if hasattr(self, "check_result"):
             self.check_result()
 
+        if hasattr(self.handler, "check_result"):
+            self.handler.check_result()
+
+class HandlerTestWithMergeInput(HandlerTestBase):
+
+    def test_merge_input_reader(self):
+        if isinstance(self.data, (list, tuple)):
+            fn = create_osm_file(self.data)
+        else:
+            fn = create_opl_file(self.data)
+
+        try:
+            self.handler = self.Handler()
+            mir = osmium.MergeInputReader()
+            with open(fn, "rb") as f:
+                data = f.read()
+                mir.add_buffer(data, format='osm')
+            mir.add_file(fn)
+            mir.apply(self.handler, idx=self.apply_idx)
+        finally:
+            os.remove(fn)
+
+        if hasattr(self, "check_result"):
+            self.check_result()
+
+        if hasattr(self.handler, "check_result"):
+            self.handler.check_result()
+
 
 class CountingHandler(osmium.SimpleHandler):
 
@@ -170,6 +199,16 @@ class CountingHandler(osmium.SimpleHandler):
         self.counts[3] += 1
 
 
+class ExecutedHandler(osmium.SimpleHandler):
+
+    def __init__(self):
+        super(ExecutedHandler, self).__init__()
+        self.has_run = False
+
+    def check_result(self):
+        assert_true(self.has_run)
+
+
 class HandlerFunction(osmium.SimpleHandler):
 
     def __init__(self, **kwargs):
